==> elasticsearch-6.1.2-sources.jar: org/elasticsearch/action/admin/cluster/settings/ClusterUpdateSettingsAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.settings;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;

public class ClusterUpdateSettingsAction extends Action<ClusterUpdateSettingsRequest, ClusterUpdateSettingsResponse, ClusterUpdateSettingsRequestBuilder> {

    public static final ClusterUpdateSettingsAction INSTANCE = new ClusterUpdateSettingsAction();
    public static final String NAME = "cluster:admin/settings/update";

    private ClusterUpdateSettingsAction() {
        super(NAME);
    }

    @Override
    public ClusterUpdateSettingsResponse newResponse() {
        return new ClusterUpdateSettingsResponse();
    }

    @Override
    public ClusterUpdateSettingsRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new ClusterUpdateSettingsRequestBuilder(client, this);
    }
}

==> elasticsearch-6.8.7-sources.jar: org/elasticsearch/action/admin/cluster/settings/ClusterUpdateSettingsAction.java <==
/*
 * Licensed to Elasticsearch under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.elasticsearch.action.admin.cluster.settings;

import org.elasticsearch.action.Action;
import org.elasticsearch.client.ElasticsearchClient;

public class ClusterUpdateSettingsAction
        extends Action<ClusterUpdateSettingsRequest, ClusterUpdateSettingsResponse, ClusterUpdateSettingsRequestBuilder> {

    public static final ClusterUpdateSettingsAction INSTANCE = new ClusterUpdateSettingsAction();
    public static final String NAME = "cluster:admin/settings/update";

    private ClusterUpdateSettingsAction() {
        super(NAME);
    }

    @Override
    public ClusterUpdateSettingsResponse newResponse() {
        return new ClusterUpdateSettingsResponse();
    }

    @Override
    public ClusterUpdateSettingsRequestBuilder newRequestBuilder(ElasticsearchClient client) {
        return new ClusterUpdateSettingsRequestBuilder(client, this);
    }
}
